# legit-api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.1.4039
- Generator version: 7.14.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import legit_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import legit_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import legit_api_client
from legit_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = legit_api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): BearerAuth
configuration = legit_api_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with legit_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = legit_api_client.AmazonEcrKeyIntegrationApi(api_client)
    id = 'id_example' # str | 

    try:
        api_instance.amazon_ecr_key_integration_delete(id)
    except ApiException as e:
        print("Exception when calling AmazonEcrKeyIntegrationApi->amazon_ecr_key_integration_delete: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AmazonEcrKeyIntegrationApi* | [**amazon_ecr_key_integration_delete**](docs/AmazonEcrKeyIntegrationApi.md#amazon_ecr_key_integration_delete) | **DELETE** /api/v1.0/integrations/amazon-ecr/key/{id} | 
*AmazonEcrRoleIntegrationApi* | [**amazon_ecr_role_integration_delete**](docs/AmazonEcrRoleIntegrationApi.md#amazon_ecr_role_integration_delete) | **DELETE** /api/v1.0/integrations/amazon-ecr/role/{id} | 
*BrokersApi* | [**api_v10_brokers_get**](docs/BrokersApi.md#api_v10_brokers_get) | **GET** /api/v1.0/brokers | Get all brokers
*CloudInstancesApi* | [**api_v10_cloud_instances_get**](docs/CloudInstancesApi.md#api_v10_cloud_instances_get) | **GET** /api/v1.0/cloud-instances | Get all cloud instances
*CollaboratorsApi* | [**api_v10_collaborators_get**](docs/CollaboratorsApi.md#api_v10_collaborators_get) | **GET** /api/v1.0/collaborators | Get all collaborators
*CollaboratorsApi* | [**api_v10_collaborators_id_get**](docs/CollaboratorsApi.md#api_v10_collaborators_id_get) | **GET** /api/v1.0/collaborators/{id} | Get collaborator by id
*CollaboratorsApi* | [**api_v10_collaborators_id_permissions_get**](docs/CollaboratorsApi.md#api_v10_collaborators_id_permissions_get) | **GET** /api/v1.0/collaborators/{id}/permissions | Get collaborator permissions
*ComplianceApi* | [**api_v10_compliance_automatic_checks_check_id_delete**](docs/ComplianceApi.md#api_v10_compliance_automatic_checks_check_id_delete) | **DELETE** /api/v1.0/compliance/automatic-checks/{checkId} | Delete automatic check
*ComplianceApi* | [**api_v10_compliance_framework_id_get**](docs/ComplianceApi.md#api_v10_compliance_framework_id_get) | **GET** /api/v1.0/compliance/{frameworkId} | Get compliance by id
*ComplianceApi* | [**api_v10_compliance_framework_id_requirement_name_automatic_checks_post**](docs/ComplianceApi.md#api_v10_compliance_framework_id_requirement_name_automatic_checks_post) | **POST** /api/v1.0/compliance/{frameworkId}/{requirementName}/automatic-checks | Create automatic check
*ComplianceApi* | [**api_v10_compliance_get**](docs/ComplianceApi.md#api_v10_compliance_get) | **GET** /api/v1.0/compliance | Get all complainces
*ComplianceApi* | [**api_v10_compliance_report_framework_id_post**](docs/ComplianceApi.md#api_v10_compliance_report_framework_id_post) | **POST** /api/v1.0/compliance/report/{frameworkId} | Request compliance report
*ContainerImagesApi* | [**api_v10_containers_cloud_instances_post**](docs/ContainerImagesApi.md#api_v10_containers_cloud_instances_post) | **POST** /api/v1.0/containers/cloud-instances | Manage container to cloud instance manual correlation
*ContainerImagesApi* | [**api_v10_containers_container_image_id_versions_get**](docs/ContainerImagesApi.md#api_v10_containers_container_image_id_versions_get) | **GET** /api/v1.0/containers/{containerImageId}/versions | Get Container Image Versions
*ContainerImagesApi* | [**api_v10_containers_get**](docs/ContainerImagesApi.md#api_v10_containers_get) | **GET** /api/v1.0/containers | Get all Container Images
*ContainerImagesApi* | [**api_v10_containers_id_get**](docs/ContainerImagesApi.md#api_v10_containers_id_get) | **GET** /api/v1.0/containers/{id} | Get Container Image By Id
*ContainerImagesApi* | [**api_v10_containers_repositories_post**](docs/ContainerImagesApi.md#api_v10_containers_repositories_post) | **POST** /api/v1.0/containers/repositories | Manage container to repository manual correlation
*CustomFieldsApi* | [**api_v10_custom_fields_get**](docs/CustomFieldsApi.md#api_v10_custom_fields_get) | **GET** /api/v1.0/custom-fields | Get Custom Fields
*IntegrationsApi* | [**api_v10_integrations_amazon_ecr_key_id_put**](docs/IntegrationsApi.md#api_v10_integrations_amazon_ecr_key_id_put) | **PUT** /api/v1.0/integrations/amazon-ecr/key/{id} | Update Amazon ECR Key integration
*IntegrationsApi* | [**api_v10_integrations_amazon_ecr_key_post**](docs/IntegrationsApi.md#api_v10_integrations_amazon_ecr_key_post) | **POST** /api/v1.0/integrations/amazon-ecr/key | Create Amazon ECR key integration
*IntegrationsApi* | [**api_v10_integrations_amazon_ecr_role_id_put**](docs/IntegrationsApi.md#api_v10_integrations_amazon_ecr_role_id_put) | **PUT** /api/v1.0/integrations/amazon-ecr/role/{id} | Update Amazon ECR Role integration
*IntegrationsApi* | [**api_v10_integrations_amazon_ecr_role_post**](docs/IntegrationsApi.md#api_v10_integrations_amazon_ecr_role_post) | **POST** /api/v1.0/integrations/amazon-ecr/role | Create Amazon ECR Role integration
*IntegrationsApi* | [**api_v10_integrations_azure_acr_id_delete**](docs/IntegrationsApi.md#api_v10_integrations_azure_acr_id_delete) | **DELETE** /api/v1.0/integrations/azure-acr/{id} | Delete Azure ACR integration by Id
*IntegrationsApi* | [**api_v10_integrations_azure_acr_id_put**](docs/IntegrationsApi.md#api_v10_integrations_azure_acr_id_put) | **PUT** /api/v1.0/integrations/azure-acr/{id} | Update Azure GCR integration
*IntegrationsApi* | [**api_v10_integrations_azure_acr_post**](docs/IntegrationsApi.md#api_v10_integrations_azure_acr_post) | **POST** /api/v1.0/integrations/azure-acr | Create Azure ACR integration
*IntegrationsApi* | [**api_v10_integrations_get**](docs/IntegrationsApi.md#api_v10_integrations_get) | **GET** /api/v1.0/integrations | Get all integrations
*IntegrationsApi* | [**api_v10_integrations_google_gcr_id_delete**](docs/IntegrationsApi.md#api_v10_integrations_google_gcr_id_delete) | **DELETE** /api/v1.0/integrations/google-gcr/{id} | Delete Google GCR integration by Id
*IntegrationsApi* | [**api_v10_integrations_google_gcr_id_put**](docs/IntegrationsApi.md#api_v10_integrations_google_gcr_id_put) | **PUT** /api/v1.0/integrations/google-gcr/{id} | Update Google GCR integration
*IntegrationsApi* | [**api_v10_integrations_google_gcr_post**](docs/IntegrationsApi.md#api_v10_integrations_google_gcr_post) | **POST** /api/v1.0/integrations/google-gcr | Create Google GCR integration
*IntegrationsApi* | [**api_v10_integrations_id_delete**](docs/IntegrationsApi.md#api_v10_integrations_id_delete) | **DELETE** /api/v1.0/integrations/{id} | Delete integration by id
*IntegrationsApi* | [**api_v10_integrations_id_get**](docs/IntegrationsApi.md#api_v10_integrations_id_get) | **GET** /api/v1.0/integrations/{id} | Get integration by id
*IntegrationsApi* | [**api_v10_integrations_jenkins_id_delete**](docs/IntegrationsApi.md#api_v10_integrations_jenkins_id_delete) | **DELETE** /api/v1.0/integrations/jenkins/{id} | Delete Jenkins integration by Id
*IntegrationsApi* | [**api_v10_integrations_jenkins_id_put**](docs/IntegrationsApi.md#api_v10_integrations_jenkins_id_put) | **PUT** /api/v1.0/integrations/jenkins/{id} | Update Jenkins integration
*IntegrationsApi* | [**api_v10_integrations_jenkins_post**](docs/IntegrationsApi.md#api_v10_integrations_jenkins_post) | **POST** /api/v1.0/integrations/jenkins | Create Jenkins integration
*IntegrationsApi* | [**api_v10_integrations_workspace_bulk_post**](docs/IntegrationsApi.md#api_v10_integrations_workspace_bulk_post) | **POST** /api/v1.0/integrations/workspace/bulk | Apply bulk workspace operation
*IssuesApi* | [**add_issue_comment**](docs/IssuesApi.md#add_issue_comment) | **POST** /api/v1.0/issues/{id}/comments | Add issue comment
*IssuesApi* | [**add_issue_tag**](docs/IssuesApi.md#add_issue_tag) | **POST** /api/v1.0/issues/{issueId}/tags/{tagId} | Add a tag to an issue
*IssuesApi* | [**create_issues_tag**](docs/IssuesApi.md#create_issues_tag) | **POST** /api/v1.0/issues/tags | Create issues tag
*IssuesApi* | [**delete_issue_comment**](docs/IssuesApi.md#delete_issue_comment) | **DELETE** /api/v1.0/issues/{issueId}/comments/{commentId} | Delete issue comment
*IssuesApi* | [**delete_issues_tag**](docs/IssuesApi.md#delete_issues_tag) | **DELETE** /api/v1.0/issues/tags/{id} | Delete issues tag
*IssuesApi* | [**get_issue_by_id**](docs/IssuesApi.md#get_issue_by_id) | **GET** /api/v1.0/issues/{id} | Get Issue by id
*IssuesApi* | [**get_issues**](docs/IssuesApi.md#get_issues) | **GET** /api/v1.0/issues | Get issues
*IssuesApi* | [**get_issues_tags**](docs/IssuesApi.md#get_issues_tags) | **GET** /api/v1.0/issues/tags | Get issues tags
*IssuesApi* | [**patch_issue_assignee**](docs/IssuesApi.md#patch_issue_assignee) | **PATCH** /api/v1.0/issues/{id}/assign | Assign user to issue
*IssuesApi* | [**patch_issue_status**](docs/IssuesApi.md#patch_issue_status) | **PATCH** /api/v1.0/issues/{id}/status | Change issue status
*IssuesApi* | [**patch_issues_statuses**](docs/IssuesApi.md#patch_issues_statuses) | **PATCH** /api/v1.0/issues/statuses | Change statuses of multiple issues
*IssuesApi* | [**remove_issue_assignee**](docs/IssuesApi.md#remove_issue_assignee) | **POST** /api/v1.0/issues/{id}/unassign | Unassign user from issue
*IssuesApi* | [**remove_issue_tag**](docs/IssuesApi.md#remove_issue_tag) | **DELETE** /api/v1.0/issues/{issueId}/tags/{tagId} | Remove a tag from an issue
*IssuesV2Api* | [**get_additional_data_by_issue_by_id**](docs/IssuesV2Api.md#get_additional_data_by_issue_by_id) | **GET** /api/v2.0/issues/{id}/additional-data | Get additional data on issue by id
*IssuesV2Api* | [**get_issue_by_id_v2**](docs/IssuesV2Api.md#get_issue_by_id_v2) | **GET** /api/v2.0/issues/{id} | Get Issue data by id
*IssuesV2Api* | [**get_issues_count**](docs/IssuesV2Api.md#get_issues_count) | **GET** /api/v2.0/issues/count | Get the issues count
*IssuesV2Api* | [**get_issues_v2**](docs/IssuesV2Api.md#get_issues_v2) | **GET** /api/v2.0/issues | Get issue ids
*PoliciesApi* | [**api_v10_policies_get**](docs/PoliciesApi.md#api_v10_policies_get) | **GET** /api/v1.0/policies | Get Policies
*PoliciesApi* | [**get_policy_by_id**](docs/PoliciesApi.md#get_policy_by_id) | **GET** /api/v1.0/policies/{id} | Get Policy by id
*PoliciesApi* | [**get_policy_by_name**](docs/PoliciesApi.md#get_policy_by_name) | **GET** /api/v1.0/policies/by-name/{name} | Get by Policy name
*ProductUnitsApi* | [**api_v10_products_get**](docs/ProductUnitsApi.md#api_v10_products_get) | **GET** /api/v1.0/products | Get all Product Units
*ProductUnitsApi* | [**api_v10_products_id_assets_get**](docs/ProductUnitsApi.md#api_v10_products_id_assets_get) | **GET** /api/v1.0/products/{id}/assets | Get Product Unit Assets
*ProductUnitsApi* | [**api_v10_products_id_custom_fields_by_name_patch**](docs/ProductUnitsApi.md#api_v10_products_id_custom_fields_by_name_patch) | **PATCH** /api/v1.0/products/{id}/custom-fields-by-name | Update Product Unit Custom Fields By Custom Field Name
*ProductUnitsApi* | [**api_v10_products_id_custom_fields_patch**](docs/ProductUnitsApi.md#api_v10_products_id_custom_fields_patch) | **PATCH** /api/v1.0/products/{id}/custom-fields | Update Product Unit Custom Fields by ID
*ProductUnitsApi* | [**api_v10_products_id_delete**](docs/ProductUnitsApi.md#api_v10_products_id_delete) | **DELETE** /api/v1.0/products/{id} | Delete Product Unit
*ProductUnitsApi* | [**api_v10_products_id_get**](docs/ProductUnitsApi.md#api_v10_products_id_get) | **GET** /api/v1.0/products/{id} | Get Product Unit by id
*ProductUnitsApi* | [**api_v10_products_id_patch**](docs/ProductUnitsApi.md#api_v10_products_id_patch) | **PATCH** /api/v1.0/products/{id} | Update Product Unit
*ProductUnitsApi* | [**api_v10_products_issuescount_get**](docs/ProductUnitsApi.md#api_v10_products_issuescount_get) | **GET** /api/v1.0/products/issuescount | Get product units issue count by severity
*ProductUnitsApi* | [**api_v10_products_post**](docs/ProductUnitsApi.md#api_v10_products_post) | **POST** /api/v1.0/products | Create new Product Unit
*RepositoriesApi* | [**api_v10_repositories_get**](docs/RepositoriesApi.md#api_v10_repositories_get) | **GET** /api/v1.0/repositories | Get all repositories
*RepositoriesApi* | [**api_v10_repositories_id_controls_get**](docs/RepositoriesApi.md#api_v10_repositories_id_controls_get) | **GET** /api/v1.0/repositories/{id}/controls | Get repository controls
*RepositoriesApi* | [**api_v10_repositories_id_get**](docs/RepositoriesApi.md#api_v10_repositories_id_get) | **GET** /api/v1.0/repositories/{id} | Get repository by id
*RepositoriesApi* | [**api_v10_repositories_id_owner_delete**](docs/RepositoriesApi.md#api_v10_repositories_id_owner_delete) | **DELETE** /api/v1.0/repositories/{id}/owner | Delete owner from repository
*RepositoriesApi* | [**api_v10_repositories_id_owner_owner_id_put**](docs/RepositoriesApi.md#api_v10_repositories_id_owner_owner_id_put) | **PUT** /api/v1.0/repositories/{id}/owner/{ownerId} | Set owner to repository
*RepositoriesApi* | [**api_v10_repositories_id_score_get**](docs/RepositoriesApi.md#api_v10_repositories_id_score_get) | **GET** /api/v1.0/repositories/{id}/score | Get repository score
*RepositoriesApi* | [**api_v10_repositories_repo_id_tags_tag_id_delete**](docs/RepositoriesApi.md#api_v10_repositories_repo_id_tags_tag_id_delete) | **DELETE** /api/v1.0/repositories/{repoId}/tags/{tagId} | Remove tag from repository
*RepositoriesApi* | [**api_v10_repositories_repo_id_tags_tag_id_post**](docs/RepositoriesApi.md#api_v10_repositories_repo_id_tags_tag_id_post) | **POST** /api/v1.0/repositories/{repoId}/tags/{tagId} | Add tag to repository
*RepositoriesApi* | [**api_v10_repositories_score_get**](docs/RepositoriesApi.md#api_v10_repositories_score_get) | **GET** /api/v1.0/repositories/score | Get repositories score
*RepositoryGroupsApi* | [**api_v10_repository_groups_get**](docs/RepositoryGroupsApi.md#api_v10_repository_groups_get) | **GET** /api/v1.0/repository-groups | Get all repository groups
*RepositoryGroupsApi* | [**api_v10_repository_groups_id_get**](docs/RepositoryGroupsApi.md#api_v10_repository_groups_id_get) | **GET** /api/v1.0/repository-groups/{id} | Get repository group by id
*SDLCAssetsApi* | [**api_v10_sdlc_assets_discovered_get**](docs/SDLCAssetsApi.md#api_v10_sdlc_assets_discovered_get) | **GET** /api/v1.0/sdlc-assets/discovered | Get all discovered SDLC assets
*SDLCAssetsApi* | [**api_v10_sdlc_assets_graph_evidence_by_ids_get**](docs/SDLCAssetsApi.md#api_v10_sdlc_assets_graph_evidence_by_ids_get) | **GET** /api/v1.0/sdlc-assets/graph/evidence/by-ids | Get SDLC asset graph evidence by Ids
*SDLCAssetsApi* | [**api_v10_sdlc_assets_graph_get**](docs/SDLCAssetsApi.md#api_v10_sdlc_assets_graph_get) | **GET** /api/v1.0/sdlc-assets/graph | Get SDLC asset graph
*SavedQueriesApi* | [**api_v10_saved_queries_saved_query_id_results_get**](docs/SavedQueriesApi.md#api_v10_saved_queries_saved_query_id_results_get) | **GET** /api/v1.0/saved-queries/{savedQueryId}/results | Get Saved Queries Results
*TagsApi* | [**api_v10_tags_get**](docs/TagsApi.md#api_v10_tags_get) | **GET** /api/v1.0/tags | Get all tags
*TagsApi* | [**api_v10_tags_post**](docs/TagsApi.md#api_v10_tags_post) | **POST** /api/v1.0/tags | Create tag
*TagsApi* | [**api_v10_tags_tag_id_delete**](docs/TagsApi.md#api_v10_tags_tag_id_delete) | **DELETE** /api/v1.0/tags/{tagId} | Delete tag
*WorkspacesApi* | [**api_v10_workspaces_get**](docs/WorkspacesApi.md#api_v10_workspaces_get) | **GET** /api/v1.0/workspaces | Get all workspaces
*WorkspacesApi* | [**api_v10_workspaces_group_post**](docs/WorkspacesApi.md#api_v10_workspaces_group_post) | **POST** /api/v1.0/workspaces/group | Create new workspace group
*WorkspacesApi* | [**api_v10_workspaces_hierarchy_get**](docs/WorkspacesApi.md#api_v10_workspaces_hierarchy_get) | **GET** /api/v1.0/workspaces/hierarchy | Get workspace hierarchy
*WorkspacesApi* | [**api_v10_workspaces_id_delete**](docs/WorkspacesApi.md#api_v10_workspaces_id_delete) | **DELETE** /api/v1.0/workspaces/{id} | Delete workspace
*WorkspacesApi* | [**api_v10_workspaces_id_get**](docs/WorkspacesApi.md#api_v10_workspaces_id_get) | **GET** /api/v1.0/workspaces/{id} | Get workspace by id
*WorkspacesApi* | [**api_v10_workspaces_permissions_post**](docs/WorkspacesApi.md#api_v10_workspaces_permissions_post) | **POST** /api/v1.0/workspaces/permissions | Add permissions to workspace/group
*WorkspacesApi* | [**api_v10_workspaces_post**](docs/WorkspacesApi.md#api_v10_workspaces_post) | **POST** /api/v1.0/workspaces | Create new workspace
*WorkspacesApi* | [**api_v10_workspaces_workspace_id_integrations_get**](docs/WorkspacesApi.md#api_v10_workspaces_workspace_id_integrations_get) | **GET** /api/v1.0/workspaces/{workspaceId}/integrations | Get integrations by workspace id


## Documentation For Models

 - [AddIssueCommentDto](docs/AddIssueCommentDto.md)
 - [AiValidationResult](docs/AiValidationResult.md)
 - [AmazonEcrKeyIntegrationCreateDto](docs/AmazonEcrKeyIntegrationCreateDto.md)
 - [AmazonEcrKeyIntegrationEditDto](docs/AmazonEcrKeyIntegrationEditDto.md)
 - [AmazonEcrRoleIntegrationCreateDto](docs/AmazonEcrRoleIntegrationCreateDto.md)
 - [AmazonEcrRoleIntegrationEditDto](docs/AmazonEcrRoleIntegrationEditDto.md)
 - [ApplyBulkWorkspaceOperationDto](docs/ApplyBulkWorkspaceOperationDto.md)
 - [ApplyBulkWorkspaceRolesOperationDto](docs/ApplyBulkWorkspaceRolesOperationDto.md)
 - [AssetConnectionDto](docs/AssetConnectionDto.md)
 - [AutomaticCheckDto](docs/AutomaticCheckDto.md)
 - [AwsRegion](docs/AwsRegion.md)
 - [AzureContainerRegistryIntegrationCreateDto](docs/AzureContainerRegistryIntegrationCreateDto.md)
 - [AzureContainerRegistryIntegrationEditDto](docs/AzureContainerRegistryIntegrationEditDto.md)
 - [BasicIssue](docs/BasicIssue.md)
 - [BrokerConnectionStatus](docs/BrokerConnectionStatus.md)
 - [BrokerDto](docs/BrokerDto.md)
 - [BrokerStatus](docs/BrokerStatus.md)
 - [BusinessImpact](docs/BusinessImpact.md)
 - [Category](docs/Category.md)
 - [ClosingReason](docs/ClosingReason.md)
 - [CloudInstanceDto](docs/CloudInstanceDto.md)
 - [CloudInstancesToContainersOperationDto](docs/CloudInstancesToContainersOperationDto.md)
 - [CollaboratorDto](docs/CollaboratorDto.md)
 - [CollaboratorRepositoryPermission](docs/CollaboratorRepositoryPermission.md)
 - [ComplianceCriteriaDto](docs/ComplianceCriteriaDto.md)
 - [ComplianceDto](docs/ComplianceDto.md)
 - [ComplianceReportDto](docs/ComplianceReportDto.md)
 - [ComplianceReportIntegrationDto](docs/ComplianceReportIntegrationDto.md)
 - [ComplianceReportRequestDto](docs/ComplianceReportRequestDto.md)
 - [ComplianceReportRequirementDto](docs/ComplianceReportRequirementDto.md)
 - [ComplianceReportWorkspaceDto](docs/ComplianceReportWorkspaceDto.md)
 - [ComplianceRequirementDto](docs/ComplianceRequirementDto.md)
 - [ComplianceWithCriteriasDto](docs/ComplianceWithCriteriasDto.md)
 - [ContainerImageDto](docs/ContainerImageDto.md)
 - [ContainerImageVersionDto](docs/ContainerImageVersionDto.md)
 - [ContainerToCloudResourceOperationDto](docs/ContainerToCloudResourceOperationDto.md)
 - [ContainerToRepositoryOperationDto](docs/ContainerToRepositoryOperationDto.md)
 - [ControlClassification](docs/ControlClassification.md)
 - [ControlSourceType](docs/ControlSourceType.md)
 - [ControlType](docs/ControlType.md)
 - [CorrelatedCloudInstance](docs/CorrelatedCloudInstance.md)
 - [CorrelatedRepositoryDto](docs/CorrelatedRepositoryDto.md)
 - [CreateAutomaticCheckDto](docs/CreateAutomaticCheckDto.md)
 - [CreateIssuesTagDto](docs/CreateIssuesTagDto.md)
 - [CreateProductUnitBadRequestDto](docs/CreateProductUnitBadRequestDto.md)
 - [CreateProductUnitDto](docs/CreateProductUnitDto.md)
 - [CreateTagDto](docs/CreateTagDto.md)
 - [CreateWorkspaceDto](docs/CreateWorkspaceDto.md)
 - [CreateWorkspaceGroupDto](docs/CreateWorkspaceGroupDto.md)
 - [CustomFieldBoolTypeDto](docs/CustomFieldBoolTypeDto.md)
 - [CustomFieldDateTypeDto](docs/CustomFieldDateTypeDto.md)
 - [CustomFieldDto](docs/CustomFieldDto.md)
 - [CustomFieldDtoType](docs/CustomFieldDtoType.md)
 - [CustomFieldEntity](docs/CustomFieldEntity.md)
 - [CustomFieldFileTypeDto](docs/CustomFieldFileTypeDto.md)
 - [CustomFieldIdentityTypeDto](docs/CustomFieldIdentityTypeDto.md)
 - [CustomFieldNumberTypeDto](docs/CustomFieldNumberTypeDto.md)
 - [CustomFieldTextTypeDto](docs/CustomFieldTextTypeDto.md)
 - [CustomFieldType](docs/CustomFieldType.md)
 - [CustomerFacingIssueDto](docs/CustomerFacingIssueDto.md)
 - [CustomerFacingIssueSourceDto](docs/CustomerFacingIssueSourceDto.md)
 - [CustomerFacingIssuesPageDto](docs/CustomerFacingIssuesPageDto.md)
 - [DastConfidenceLevel](docs/DastConfidenceLevel.md)
 - [DependencyFixType](docs/DependencyFixType.md)
 - [DetailedSdlcAssetInformationDto](docs/DetailedSdlcAssetInformationDto.md)
 - [DiscoveredSdlcAssetDto](docs/DiscoveredSdlcAssetDto.md)
 - [DiscoveryConnectionEvidenceType](docs/DiscoveryConnectionEvidenceType.md)
 - [FrameworkPolicyType](docs/FrameworkPolicyType.md)
 - [GetCustomFieldsResponseDto](docs/GetCustomFieldsResponseDto.md)
 - [GetSdlcAssetGraphEvidenceByIdsResponseDto](docs/GetSdlcAssetGraphEvidenceByIdsResponseDto.md)
 - [GoogleContainerRegistryIntegrationCreateDto](docs/GoogleContainerRegistryIntegrationCreateDto.md)
 - [GoogleContainerRegistryIntegrationEditDto](docs/GoogleContainerRegistryIntegrationEditDto.md)
 - [IntegrationBadResponseDto](docs/IntegrationBadResponseDto.md)
 - [IntegrationDto](docs/IntegrationDto.md)
 - [IntegrationError](docs/IntegrationError.md)
 - [IntegrationFailingReason](docs/IntegrationFailingReason.md)
 - [IntegrationManagementDto](docs/IntegrationManagementDto.md)
 - [IntegrationStatus](docs/IntegrationStatus.md)
 - [IntegrationType](docs/IntegrationType.md)
 - [IssueAssignment](docs/IssueAssignment.md)
 - [IssueClosingLocationDto](docs/IssueClosingLocationDto.md)
 - [IssueCommentDto](docs/IssueCommentDto.md)
 - [IssueCountBySeverityDto](docs/IssueCountBySeverityDto.md)
 - [IssueDto](docs/IssueDto.md)
 - [IssueIgnoringReasonDto](docs/IssueIgnoringReasonDto.md)
 - [IssueOpeningReasonDto](docs/IssueOpeningReasonDto.md)
 - [IssueOriginDto](docs/IssueOriginDto.md)
 - [IssueOriginParams](docs/IssueOriginParams.md)
 - [IssueSortingColumn](docs/IssueSortingColumn.md)
 - [IssueStatus](docs/IssueStatus.md)
 - [IssueTagDto](docs/IssueTagDto.md)
 - [IssueTicketingDto](docs/IssueTicketingDto.md)
 - [IssueType](docs/IssueType.md)
 - [IssuesTagDto](docs/IssuesTagDto.md)
 - [JenkinsIntegrationCreateDto](docs/JenkinsIntegrationCreateDto.md)
 - [JenkinsIntegrationEditDto](docs/JenkinsIntegrationEditDto.md)
 - [LegitScoreCategoryDto](docs/LegitScoreCategoryDto.md)
 - [LegitScoreDto](docs/LegitScoreDto.md)
 - [LegitScoreGrade](docs/LegitScoreGrade.md)
 - [LegitScoreRequirementDto](docs/LegitScoreRequirementDto.md)
 - [LegitScoreRequirementGroupType](docs/LegitScoreRequirementGroupType.md)
 - [LegitScoreRequirementType](docs/LegitScoreRequirementType.md)
 - [ListSortDirection](docs/ListSortDirection.md)
 - [ManualCheckDto](docs/ManualCheckDto.md)
 - [OriginType](docs/OriginType.md)
 - [PatchLegitIssueAssigneeDto](docs/PatchLegitIssueAssigneeDto.md)
 - [PatchLegitIssueStatusDto](docs/PatchLegitIssueStatusDto.md)
 - [PatchLegitIssueUnifiedStatusDto](docs/PatchLegitIssueUnifiedStatusDto.md)
 - [PatchLegitIssuesStatusDto](docs/PatchLegitIssuesStatusDto.md)
 - [PatchProductUnitCustomFieldByName](docs/PatchProductUnitCustomFieldByName.md)
 - [PatchProductUnitCustomFieldDto](docs/PatchProductUnitCustomFieldDto.md)
 - [PatchProductUnitCustomFieldsByNameDto](docs/PatchProductUnitCustomFieldsByNameDto.md)
 - [PatchProductUnitCustomFieldsDto](docs/PatchProductUnitCustomFieldsDto.md)
 - [PatchProductUnitDto](docs/PatchProductUnitDto.md)
 - [PatchSecurityChampionIdDto](docs/PatchSecurityChampionIdDto.md)
 - [PermissionMetaType](docs/PermissionMetaType.md)
 - [PolicyDto](docs/PolicyDto.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [ProductConnectionType](docs/ProductConnectionType.md)
 - [ProductTreeNodeDto](docs/ProductTreeNodeDto.md)
 - [ProductUnitAssetDto](docs/ProductUnitAssetDto.md)
 - [ProductUnitDto](docs/ProductUnitDto.md)
 - [ProductUnitDtoCustomFieldsValue](docs/ProductUnitDtoCustomFieldsValue.md)
 - [ProductUnitEnvironment](docs/ProductUnitEnvironment.md)
 - [ProductUnitNameDto](docs/ProductUnitNameDto.md)
 - [ProductUnitType](docs/ProductUnitType.md)
 - [RepositoriesToContainersOperationDto](docs/RepositoriesToContainersOperationDto.md)
 - [RepositoryControlDto](docs/RepositoryControlDto.md)
 - [RepositoryDirectory](docs/RepositoryDirectory.md)
 - [RepositoryDto](docs/RepositoryDto.md)
 - [RepositoryGroupDto](docs/RepositoryGroupDto.md)
 - [RepositoryVisibility](docs/RepositoryVisibility.md)
 - [ScmType](docs/ScmType.md)
 - [SdlcAssetDto](docs/SdlcAssetDto.md)
 - [SdlcAssetGraphAssetDto](docs/SdlcAssetGraphAssetDto.md)
 - [SdlcAssetGraphDto](docs/SdlcAssetGraphDto.md)
 - [SdlcAssetGraphEvidenceDto](docs/SdlcAssetGraphEvidenceDto.md)
 - [SdlcAssetGraphLinkDto](docs/SdlcAssetGraphLinkDto.md)
 - [SdlcAssetGraphLinkDtoEvidences](docs/SdlcAssetGraphLinkDtoEvidences.md)
 - [SdlcAssetMetaType](docs/SdlcAssetMetaType.md)
 - [SdlcAssetType](docs/SdlcAssetType.md)
 - [SecretIssueValidityStatus](docs/SecretIssueValidityStatus.md)
 - [Severity](docs/Severity.md)
 - [SnoozedType](docs/SnoozedType.md)
 - [TagDto](docs/TagDto.md)
 - [TagSource](docs/TagSource.md)
 - [UserDto](docs/UserDto.md)
 - [UserPermission](docs/UserPermission.md)
 - [UserRole](docs/UserRole.md)
 - [WorkspaceCreatedDto](docs/WorkspaceCreatedDto.md)
 - [WorkspaceDto](docs/WorkspaceDto.md)
 - [WorkspaceGroupDto](docs/WorkspaceGroupDto.md)
 - [WorkspaceGroupTreeNodeDto](docs/WorkspaceGroupTreeNodeDto.md)
 - [WorkspaceHierarchyDto](docs/WorkspaceHierarchyDto.md)
 - [WorkspaceTreeNodeDto](docs/WorkspaceTreeNodeDto.md)
 - [WorkspaceType](docs/WorkspaceType.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication (JWT)


## Author




